function [gcv,gcvtop,gcvbot,trr,e,r] = gcv_func2_box(logsmp)

% @(#)   gcv_func2_box.m  version 1.3  created 92/10/20
%----------------------------------------------------------------------------
% function [gcv,gcvtop,gcvbot,trr,e,r] = gcv_func2_box(logsmp)
%
%             Computes scalar GCV as a function of log10(smoothing parameter)
%             using method 2 [Menke (1984), p.55, equation (3.40)]. This
%             version allows only one smoothing parameter. Function depends
%             on pre-defined global variables which are detailed in
%             gcv_global_box.m. Minimized using fmin - hence the global
%             variables.
%----------------------------------------------------------------------------

% References: Wahba & Wendelberger (1980), Menke (1984)
%             McIntosh & Veronis (1993)
% Author:     Peter McIntosh
% History:    See SCCS comments

%----------------------------------------------------------------------------
[m,n]    = size(glb_a);
smp      = 10^logsmp;
smp2     = smp*smp;

c        = glb_a_wm_inv_at+smp2*glb_we_inv;
z        = c\[glb_b,eye(m)];
glb_x = glb_wm_inv_at*z(:,1);
r        = eye(m)-smp2*glb_we_inv*z(:,2:m+1);
e        = glb_a*glb_x-glb_b;

gcvtop   = e'*glb_we*e/m;
trr      = trace(r);
tr       = m-trr;
gcvbot   = tr*tr/(m*m);
gcv      = gcvtop/gcvbot;
%----------------------------------------------------------------------------
