function glb_gcv_method = gcv_method_box(we,wm_or_c,is_wm)

% @(#)   gcv_method_box.m  version 1.3  created 92/12/16
%----------------------------------------------------------------------
% FUNCTION glb_gcv_method = gcv_method_box(we,wm_or_c,is_wm)
%
% Decide on GCV method to use based on properties of weight matrices
%
% Input:  we        square of row (equation) weight matrix  (MxM)
%         wm_or_c   norm/semi-norm or column weight matrix  (NxN)
%         is_wm     1 if wm_or_c is norm/semi-norm weight matrix
%                   otherwise, assumed to be column weight matrix
%
% Output: glb_gcv_method = 1 for Menke (1984) equation (3.39)
%                        = 2 for Menke (1984) equation (3.40)
%
% Calls:  issym_box
%----------------------------------------------------------------------

% Reference: Menke (1984)
% Author:    Peter McIntosh
% History:   See SCCS comments

%----------------------------------------------------------------------

%...Test that all matrices are symmetric...

wesym=issym_box(we);
if wesym~=1,
  error('We not symmetric');
end

wmsym=issym_box(wm_or_c);
if wmsym~=1,
  if is_wm~=1,
    error('C not symmetric');
  else
    error('Wm not symmetric');
  end
end

%...Now test rank of weight matrices and set method number accordingly...

if rank(we)~=length(we)
  if is_wm~=1,
    if rank(wm_or_c)~=length(wm_or_c),
      error('Both row and column weight matrices singular!');
    end
  end
  disp('We rank deficient: using GCV method #1');
  glb_gcv_method=1;
else
  if is_wm~=1,
    if rank(wm_or_c)~=length(wm_or_c),
      disp('C rank deficient: using GCV method #2');
      glb_gcv_method=2;
    else
      disp('C OK: using GCV method #2');
      glb_gcv_method=2;
    end
  else
    if rank(wm_or_c)~=length(wm_or_c)
      disp('Wm rank deficient: using GCV method #1');
      glb_gcv_method=1;
    else
      disp('Wm OK: using GCV method #1');
      glb_gcv_method=1;
    end
  end
end

%----------------------------------------------------------------------
