function sn = make_sn_box(dim,order)

% @(#)   make_sn_box.m  version 1.1  created 92/12/16
%----------------------------------------------------------------------------
% function sn = make_sn_box(dim,order)
%
%        Constructs semi-norm weight matrix sn for vectors with number of
%        spatially contiguous elements given by elements of row vector dim.
%        e.g. if vector has 35 followed by 42 spatially contiguous
%        elements, then dim = [35 42]. Differential order is specified in
%        "order", which is either a scalar or the same dimension as dim.
%        Differential order must be non-negative.
%        If deriv is difference matrix, sn=deriv'*deriv.
%----------------------------------------------------------------------------

% Reference: McIntosh and Veronis (1993)
% Author:    Peter McIntosh
% History:   PCM 17/9/91 - created
%            PCM 14/7/92 - order can now be a vector

%----------------------------------------------------------------------------

if length(find(order<0))~=0,
  error('make_sn_box: differential order must be non-negative.');
end

ncontig = length(dim);
norder  = length(order);
if length(order)==1,
  vorder=order*ones(dim);
else
  if norder~=ncontig,
    error('make_sn_box: different dimensions of "dim" and "order".');
  end
  vorder=order;
end

if norder==1 & order==0
  len = sum(dim);
  sn  = eye(len);
else
  deriv   = diff(eye(dim(1)),vorder(1));
  sn      = deriv'*deriv;
  for i=2:ncontig
    next  = diff(eye(dim(i)),vorder(i));
    next2 = next'*next;
    [m,n] = size(sn);
    [p,q] = size(next2);
    sn    = [sn zeros(m,q);zeros(p,n) next2];
  end
end
%----------------------------------------------------------------------------
