%===================================================================
% ANAL_MENU   4.4   93/07/06   Copyright (C) Phil Morgan 1992.
%
% DESCRIPTION:
%   Analyse results of box modelling
% 
% CALLER:   dobox.m
% CALLEE:   plote.m prflux.m
%
% AUTHOR:   Phil Morgan 92-01-20
%==================================================================

%  @(#)anal_menu.m  Revision: 4.4  Date: 93/07/06
%--------------------------------------------------------------------


% DISPLAY ANALYSE MENU
anal_menu_stop = 0;
anal_menu_opt = 0;

while anal_menu_stop==0
   disp('				')
   disp('----- Analysis of Box results ----- ')
   disp('				')
   disp('      1) R for section 	')
   disp('      2) N for box		')
   disp('      3) x for section		')
   disp('				')
   disp('      4) Section       Transport	        ')
   disp('      5) Net section   Transport		')
   disp('      6) Net box       Transport		')
   disp('      7) Ekman section Transport               ')
   disp('				                   ')
   disp('      8) Print table of section fluxes to screen  ')
   disp('      9) Keyboard - enter your command  	   ')
   disp('				                   ')
   disp('     10) Box Lateral & Net transports	')   
   disp('     11) Plot Xrows/Xcols transport	')   
   disp('     			                ')      
   disp('      0) Main Menu		') 
   disp('				')
 
   defnum = anal_menu_opt + 1;
   anal_menu_opt = input([' Select a menu number: {' num2str(defnum) '} ']);
 
   if     anal_menu_opt == 0
     anal_menu_stop = 1;
    
   elseif anal_menu_opt == 1
    disp(' ')
    disp(' Plot R - model (column) resolution of a section')
    isect = getinput('What section number ? ',1,length(col_beg));
    
    clg
    plot( diagR( col_beg(isect):col_end(isect) ) )
    ylabel('Resolution (0-1)')
    if isect <= nsections
       title(['Model Resolution - section ' num2str(isect) ])
       xlabel('Station Pair index')
    else
        title(['Model Resolution '])      
        xlabel('Xcols index')
    end %if
    disp('**** Plot Option 1 Done ****')
    
  elseif anal_menu_opt == 2
    disp(' ')
    disp(' Plot N - data (row) resolution of a box')
    ibox = getinput('What box number ? ',1,length(row_beg));
    
    clg
    plot( diagN(row_beg(ibox) : row_end(ibox) ))
    ylabel('Resolution (0-1)')
    if ibox <= nboxes
       title(['Data Resolution - box '  num2str(ibox) ])
       xlabel('Equation index')
    else
        title(['Data Resolution '])      
        xlabel('Xrows index')
    end %if
    disp('**** Plot Option 2 Done ****')
    
  elseif anal_menu_opt == 3
    disp(' ')
    disp(' Plot x for a section')
    isect = getinput('What section number ? ',1,length(col_beg));      
    
    clg
    plot( x( col_beg(isect) : col_end(isect) ))
    hold on
    plot( x( col_beg(isect) : col_end(isect) ), 'o')
    ylabel('x - (m/s)')
    if isect <= nsections
       title(['Ref. velocity (x) for section '  num2str(isect) ])
       xlabel('Station Pair index')
    else
       title(['Velocity (x) for Xcols'])
       xlabel('Xcols index')      
    end %if
    hold off
    disp('**** Plot Option 3 Done ****')

  elseif anal_menu_opt == 4
    disp(' Plots relative (TL) and reference (TF) property')
    disp(' transports for a section in a box')
    ibox  = getinput('What box number ? ',1,nboxes);    
    isect = getinput('What section number ? ',1,nsections);          
    iprop = getinput('What property number ? ',1,nproperties);
    row1  = row_beg(ibox) + eqn_beg(iprop);
    row2  = row_beg(ibox) + eqn_end(iprop);
    rows  = [ row1  : row2 ];
    cols  = [ col_beg(isect) : col_end(isect) ];

    hold off
    clg

    subplot(221)
    %----------
    bar( sum(TF( rows, cols)) );
    title(['TF box ' num2str(ibox) ' section ' num2str(isect) ' prop ' num2str(iprop) ])
    xlabel('Station Pair index')
    
    subplot(223)
    %----------
    bar( sum(TL( rows, cols)) );
    title(['TL box ' num2str(ibox) ' section ' num2str(isect) ' prop ' num2str(iprop) ])
    xlabel('Station Pair index')    

    subplot(222)    
    %-----------
    bar( sum(TF( rows, cols)') );
    title(['TF box ' num2str(ibox) ' section ' num2str(isect) ' prop ' num2str(iprop) ])
    xlabel('layer')

    subplot(224)    
    %----------
    bar( sum(TL( rows, cols)') );
%   [XX,YY] = bar( sum(TLbox(1:nlayers,:)') );
%   plot(YY,-XX; hold on; plot([0 0], [0 -nlayers]); hold off
    title(['TL box ' num2str(ibox) ' section ' num2str(isect) ' prop ' num2str(iprop) ])
    xlabel('layer')    

    subplot(111)
    disp('**** Plot Option 4 Done ****')
    
  elseif anal_menu_opt == 5
    disp('Plots net property transport for a section of a box')
    ibox =  getinput('What box number ? ',1,nboxes);    
    isect = getinput('What section number ? ',1,nsections);          
    iprop = getinput('What property number ? ',1,nproperties);
    row1  = row_beg(ibox) + eqn_beg(iprop);
    row2  = row_beg(ibox) + eqn_end(iprop);
    rows  = [ row1  : row2 ];
    cols  = [ col_beg(isect) : col_end(isect) ];
    
    hold off
    clg
    
    subplot(211)
    %----------
    bar( sum(TA(rows,cols)));
    title(['TA box ' num2str(ibox) ' section ' num2str(isect) ' prop ' num2str(iprop) ])
    xlabel('Station Pair index')
    
    subplot(212)
    %----------
    bar( sum(TA(rows,cols)') );
    title(['TA box ' num2str(ibox) ' section ' num2str(isect) ' prop ' num2str(iprop) ])
    xlabel('layer')    

    subplot(111)    
    disp('**** Plot Option 5 Done ****')
    
  elseif anal_menu_opt == 6
    disp('Plots net property flux into box')
    ibox  = getinput('What box number ? ',1,nboxes);    
    iprop = getinput('What property number ? ',1,nproperties);    
    row1  = row_beg(ibox) + eqn_beg(iprop);
    row2  = row_beg(ibox) + eqn_end(iprop);
    rows  = [ row1  : row2 ];

    for isect = 1:nsections
      cols         = [ col_beg(isect) : col_end(isect) ];
      TAbox(isect) = sum( sum(TA(rows,cols)));
    end
    
    hold off
    clg
    
    subplot(211)
    %----------
    bar( TAbox )
    title(['Net flux of prop ' num2str(iprop) ' per section into box ' num2str(ibox) ])
    xlabel('section number')
    ylabel('flux')
    clear TAbox

    subplot(212)
    %----------
    % lateral and vertical (if any) tranport , RHS .  THUS net.
    TAnet = sum(TF( rows , : )' )' - b(rows);
    bar( TAnet )
%   bar(sum (TA( rows , col_beg(1):col_end(nsections) ) )' )
    title(['Net flux of prop ' num2str(iprop) ' into layer in box ' num2str(ibox) ])
    xlabel('layer number')
    ylabel('flux')
    clear TAnet
    
    subplot(111)    
    disp('**** Plot Option 6 Done ****')
    
  elseif anal_menu_opt == 7
    plote
    subplot(111)    
    
  elseif anal_menu_opt == 8
    prflux    
    subplot(111)    
      
  elseif anal_menu_opt == 9
     disp(' ')
     disp('Enter your command eg print.  Type "return" to continue')
     keyboard

  elseif anal_menu_opt == 10
    disp('Plots net property flux into box')
    ibox  = getinput('What box number ? ',1,nboxes);    
    iprop = getinput('What property number ? ',1,nproperties);    
    row1  = row_beg(ibox) + eqn_beg(iprop);
    row2  = row_beg(ibox) + eqn_end(iprop);
    rows  = [ row1  : row2 ];

    hold off
    clg
    
    subplot(221)
    %----------
    TFlat = sum(TF( rows ,col_beg(1):col_end(nsections) )' )';
    bar( TFlat )
    title(['Lateral flux prop ' num2str(iprop) ', box ' num2str(ibox) ])
    xlabel('layer number')
    ylabel('flux')
    
    subplot(222)
    %----------
    % vertial transports
    if nsections+1>length(col_beg)
       TFvert = zeros(size( b(rows) ));
    else
       TFvert = sum(TF( rows ,col_beg(nsections+1):col_end(nsections+1) )' )';
    end %if
    bar( TFvert )
    title(['Vertical flux prop ' num2str(iprop) ', box ' num2str(ibox) ])
    xlabel('layer number')
    ylabel('flux')

    
    subplot(223)
    %----------
    % RHS.  ReLative transports
    bar( -b(rows) )
    title(['RHS flux prop ' num2str(iprop) ', box ' num2str(ibox) ])
    xlabel('layer number')
    ylabel('flux')
    
    subplot(224)
    %----------
    % all columns, incl vertial transports
    TFnet = sum(TF( rows , : )' )' - b(rows);
    bar( TFnet )
    title(['Net flux prop ' num2str(iprop) ', box ' num2str(ibox) ])
    xlabel('layer number')
    ylabel('flux')
    
    % PRINT TABLES OF TRANSPORTS - ROUGH
    disp( '---------------------------------------------')
    disp('         TABLE OF LAYER TRANSPORTS')
    disp(['   TFlat     TFvert     TFnet      b(rows)  '])
    disp( '---------------------------------------------')
    fprintf(1,'%10.3e %10.3e %10.3e %10.3e\n', [TFlat TFvert TFnet b(rows)]')
    clear TFlat TFvert TFnet

    subplot(111)    
    
  elseif anal_menu_opt == 11
     xplots
     subplot(111)     
     
  else
     anal_menu_opt = defnum -1;
  end
end

clear anal_menu_opt anal_menu_stop defnum 
return
%--------------------------------------------------------------------
