function [CWrel, CWmag, XCW, file_CWrel, file_CWmag, file_XCW] = ...
         colweight(XCW, Abasedash, Amasstot)


% COLWEIGHT  Menu for Column weighting options
%===================================================================
% COLWEIGHT   3.9   93/10/24   Copyright (C) Phil Morgan 1992.
%
% DESCRIPTION:
%    Menu for Column weighting options
%
% CALLER:   weights_menu.m
% CALLEE:   
%
% AUTHOR:   Phil Morgan 92-12-15
%==================================================================


% @(#)colweight.m  Revision: 3.9  Date: 93/10/24
%--------------------------------------------------------------------

file_CWrel = [];
file_CWmag = [];
file_XCW   = [];
CWrel      = [];
CWmag      = [];
   
[mAbase,nAbase] = size(Abasedash);


CW_menu_stop = 0;
while CW_menu_stop == 0
    clc
    disp(' ')
    disp('----- COLUMN WEIGHT MENU (512) -----                          ')
    disp(' 							')
    disp('  You may select options from 3 separate actions ... ')
    disp(' 							')
    disp(' 							')
    disp('  OPTIONS FOR RELATIVE COLUMN WEIGHTS (CWrel):	')
    disp('      1) Set CWrel to ones ')
    disp('      2) Set CWrel from *.m file ')
    disp(' 							')
    disp('  OPTIONS FOR MAGNITUDE OF COLUMN WEIGHTS (CWmag):		')     
    disp('      3) Ones - Identity              ')
    disp('      4) Norm of each column          ')
    disp('      5) Normalise with Pair Area     ')    
    disp('      6) Enter user defined CWmag from *.mat file')
    disp(' 							    ')
    disp('  OPTIONS for XCW				')
    disp('      7) Reset XCW from *.m file (overrides BUILD menu)   ')
    disp('                                                          ')
    disp('      0) WEIGHTS menu      ')
    disp('         (defaults are options 1. and 3.) ')    
    disp('         ')    
    disp(' 							')
    
   CW_menu_opt = input([' Select a menu number: ']);

  if     CW_menu_opt == 0
    % VERIFY DIMENSIONS OF "CWrel"
    if ~isempty(CWrel)
       CWrel = CWrel(:)';  %force to row vector
       if nAbase~=length(CWrel)
          disp('CWrel does not have the correct dimensions.')
          error(['Must have ' num2str(nAbase) ' elements'])
       end %if
    end %if

    % VERIFY DIMENSIONS OF "CWmag"
    if ~isempty(CWmag)
       CWmag = CWmag(:)';  %force to row vector 
       if nAbase~=length(CWmag)
           disp('CWmag does not have the correct dimensions.')
           error(['Must have ' num2str(nAbase) ' elements'])
       end %if
    end %if
    
    % ENSURE "XCW" IS DEFINED AND IS A ROW VECTOR
    XCW = XCW(:)';  %force to row vector

    CW_menu_stop = 1;

    
  elseif CW_menu_opt == 1
    CWrel = ones(1,nAbase);    
    file_CWrel = 'ones';
    disp(' ')
    disp('*** colweight option 1 - done ***')
    disp(' ')

    
  elseif CW_menu_opt == 2
    % LOAD IN VARIABLE "CWrel"
    file_CWrel = input('What Relative col weights *.m file ? ','s');
    if exist(file_CWrel) ~= 2
       error(['CWrel mfile ' file_CWrel ' not found'])
    end %if
    eval(file_CWrel); %load in vector "CWrel"
 
    disp(' ')
    disp('*** colweight option 2 - done ***')
    disp(' ')    


  elseif CW_menu_opt == 3
     file_CWmag = 'ones';
     CWmag      = ones(1,nAbase);
  
    disp(' ')
    disp('*** colweight option 3 - done ***')
    disp(' ')    
    

  elseif CW_menu_opt == 4
    file_CWmag = 'Column Norm';
    CWmag      = diag( colwts(Abasedash) )';  % to get a row vector

    disp(' ')
    disp('*** colweight option 4 - done ***')
    disp(' ')    
      

  elseif CW_menu_opt == 5
     file_CWmag      = 'Normalise Pair Area';
     flag            = find(Amasstot==0);
     Amasstot(flag)  = ones(size(flag));
     Amasstotw       = [ones(size(Amasstot)) ./ Amasstot];
     Amasstotw       = sqrt(Amasstotw);
     Amasstotw(flag) = zeros(size(flag));
     CWmag           = Amasstotw; 
    
    disp(' ')
    disp('*** colweight option 5 - done ***')
    disp(' ')    
    
    
  elseif CW_menu_opt == 6
    file_CWmag = input('What *.mat filename for CWmag ? ','s');
    % CHECK IF FILE "filename" EXISTS.
    [file_CWmag,fileok] = validfile(file_CWmag,'.mat');
    if fileok
       disp([' Loading file {' file_CWmag '}. Please wait...'])
       [CWmag] = loadvars(file_CWmag,'CWmag');
    else
       disp([' WARNING: file {' file_CWmag '} not found.'])
    end %if
   
    disp(' ')
    disp('*** colweight option 6 - done ***')
    disp(' ')
    
    
  elseif CW_menu_opt == 7

    % LOAD IN VARIABLE "XCW" 
    file_XCW = input('What XCW weights *.m file ? ','s');
    if exist(file_XCW) ~= 2
       error(['XCW weights mfile ' file_XCW ' not found'])
    end %if
    eval(file_XCW);
 
    disp(' ')
    disp('*** colweight option 7 - done ***')
    disp(' ')    
    
  end %if CW_menu_opt

end

clear CW_menu_opt CW_menu_stop
return
%--------------------------------------------------------------------

