% DOBOX_MENU   Menu for constructing, solving and analysing box models
%===================================================================
% DOBOX_MENU    4.8   93/10/13   Copyright (C) Phil Morgan  1991-3
%
% DESCRIPTION:
%   Menu for constructing, solving and analysing box model results.
% 
% CALLER:   dobox.m - main driver
% CALLEE:   many as shown.
%
% AUTHOR:   Phil Morgan 91-02-03
%==================================================================

% @(#)%M   Revision: 4.8   Date: 93/10/13
%--------------------------------------------------------------------

 
box_menu_stop = 0;
box_menu_opt = 1;

while box_menu_stop == 0
    clc
    disp(' ')
    disp('***************************************************************')
    disp('**            DOBOX Release 4.2                              **')
    disp('***************************************************************')
    disp(' 						')
    disp('----- BOX MENU (0) : Model Choices -----')
    disp(' 						')
    disp('      1) Prepare      -    Raw Section file for dobox      ')
    disp(' 						                ')   
    disp('      2) Lhs          -    Define geometry,  Build Abase 	')
    disp('      3) Rhs ...      -    Set reflevel Build bbase 	')
    disp('      4) Build ...    -    Define extra Row/Columns, Build A & b')
    disp('  							          ')
    disp('      5) Weights ...  -    Define Row/Column weighting          ')
    disp('      6) Solve ...    -    Set method, Solve Ax=b, Evaluate transports')
    disp('      7) Analyse ...  -    Analysis plots 			')
    disp('  				')
    disp('      0) Matlab       -    Return to MATLAB 		')
    disp('  							')
    
    defnum = box_menu_opt + 1;
    box_menu_opt = input([' Select a menu number: {' num2str(defnum) '} ']);

  if     box_menu_opt == 0   % return to MATLAB
    box_menu_stop = 1;
    
  elseif box_menu_opt == 1   % Process a Section
    disp(' ')
    disp('This gets the raw matlab data file for a section and calculates');
    disp('layer thickness and the average value of the tracer in the areas');
    disp('of the walls of the box and stores the results in a named file');
    disp(' ')
    raw_filename = input('What raw (section) file name ? ','s');
    properties   = input('What are the properties ? ');
    sectfile     = dosection(raw_filename,properties);
    clear file
    disp(' ')
    disp('*** Option 1 - dosection - Done ****');
    disp(' ')
    
  elseif box_menu_opt == 2
    file_geom = input('What geometry file ? ','s');
    eval(file_geom); 

    [Abase, nlayers, nsectpairs] = build_a(geometry, sectfiles, properties);

    [mAbase,nAbase]     = size(Abase);
    [nproperties,m]     = size(properties);
    [nboxes,nsections]  = size(geometry);
    nboxeqns            = (nlayers+1)*nproperties;
    nsurfs              = nlayers + 1;
    clear m

    [row_beg, row_end, col_beg, col_end, eqn_beg, eqn_end] = ...
          set_index(nboxes,nsections,nproperties,nsectpairs,nlayers,nboxeqns);

    disp(' ')
    disp('*** Option 2 - Build A - Done ****');
    disp(' ')

  elseif box_menu_opt == 3
    [DL,E,D,bbase,reflevel] = ... 
          rhs_menu(geometry,sectfiles,properties,nsurfs,DL,E,D,bbase,reflevel);

    disp(' ')
    disp('*** Option 3 - Build DL, E, D & b -  Done ****');
    disp(' ')

  elseif box_menu_opt == 4
    disp(' ')
    [Xrows,Xcols,Xbs,XRW,XCW,file_Xrows,file_Xcols] = get_extra(mAbase,nAbase);
    [Xzeros] = verify_extra(Xrows, Xcols, Xbs, XRW, XCW, mAbase, nAbase);

    % CONSTRUCT FULL A AND b MATRIX
    A = [Abase Xcols  ;
	 Xrows Xzeros ];
    b = [bbase ;
	 Xbs   ];
    [mA,nA] = size(A);

    [row_beg,row_end,col_beg,col_end] = ...
         set_xindex(Xrows,Xcols,row_beg,row_end, ...
                    col_beg,col_end,nboxes,nsections);

    disp(' ')
    disp('*** Option 4 - set row/col constraints -  Done ****');
    disp(' ')
 
  elseif box_menu_opt == 5
    weights_menu;
    disp('  ')
    disp('*** Option 5 - weights_menu - Done ****');
    disp(' ')   
    
  elseif box_menu_opt == 6
    method_menu;

    if (~exist('R') | isempty(R))
       disp(' ')
       disp('No solution determined. Returning to main menu')
       disp(' ')
    else
      diagR = diag(R);
      diagN = diag(N);

      TF    = zeros(size(A));
      for i=1:mA
        TF(i,:) = A(i,:) .* x';
      end
      clear i
    
      TL = DL;
      TA =TF( row_beg(1):row_end(nboxes), col_beg(1):col_end(nsections))+TL+E;
    end %if

    disp(' ')
    disp('*** Option 6 - method_menu - Done ****');
    disp(' ')   
   
  elseif box_menu_opt == 7
    if (~exist('R') | isempty(R))
       error('dobox: No solution determined in option 6')
    else
       anal_menu;
    end %if
    disp(' ')
    disp('*** Option 7 - anal_menu -  Done ****');
    disp(' ')
   
  else
    box_menu_opt = defnum - 1;

  end %if
end %while

clear box_menu_opt box_menu_stop defnum
return

%--------------------------------------------------------------------


