function [itaux,itauy]=getecmwf(ylat,xlong)

%===================================================================
% GETECMWF   3.1  92/04/03
%
% [ctaux,ctauy]=getecmwf(ylat,xlong)
%
% DESCRIPTION:
%    Interpolates the ecmwf wind stress dataset for the wind stress at the
%    desired position(s).
% 
% INPUT:
%    ylat   = vector latitudes  for wind stress. Decimal degrees (+ve N, -ve S)
%    xlong  = vector longitudes for wind stress. Decimal degrees (+ve E, -ve W)
%
% OUTPUT:
%    itaux  = interpolated wind stress component in x (E) direction 
%    itauy  = interpolated wind stress component in y (N) direction
%                units are dynes/cm2
%
% DATA:     /home/morgan/datasets/ecmwf/ecmwfdata.mat
%
% AUTHOR:   Phil Morgan 17-02-92
%==================================================================

% @(#)getecmwf.m   3.1   92/04/03
%--------------------------------------------------------------------

load /home/morgan/datasets/ecmwf/ecmwfdata.mat

[m,n]=size(tauy);
if m~=size(lat)
  error('GETECMWF.M: lat wrong dims')
end %if
if n~=size(long)
  error('GETECMWF.M: long wrong dims')
end %if

taux = change(taux,'<',-90,NaN);
tauy = change(tauy,'<',-90,NaN);

tabx = [0 long; lat' taux];
taby = [0 long; lat' tauy];

for i=1:length(xlong)
  [itaux(i)]=table2(tabx,ylat(i),xlong(i));
  [itauy(i)]=table2(taby,ylat(i),xlong(i));
end

%---------------------------------------------------------------------------

