function [fbox] = getfluxes(sectfile, properties, reflevel)

%=======================================================================
% GETFLUXES   4.2   93/07/05   Copyright (C) Phil Morgan 1992
%
% [fbox] = getfluxes(sectfile, properties, reflevel)
%
% DESCRIPTION:
%    Calculates the integrated flux of each property for each neutral
%    surface layer at each station pair using the high resolution binned
%    ctd data files.
%
% INPUT:
%    sectfile   = a section filename.  See build_dl.m for details.
%    reflevel   = the "surface" level number to use as the geostrophic
%                 reference level. (old "level of no motion" notion).
%
% OUTPUT:
%    fbox       = integrated flux of each property in layers between 
%                 "surfaces" and "total" flux.    
%
% AUTHOR:   Phil Morgan  20-03-92.
%=======================================================================

% @(#)getfluxes.m  Revision: 4.2  Date: 93/07/05
%=======================================================================
TRUE  = 1;
FALSE = 0;

[bin_press, Layer_press] = loadvars(sectfile,'bin_press','Layer_press');
[deldistkm,nsurfs,npairs]  = ...
    loadvars(sectfile,'deldistkm','nsurfs','npairs');
nlayers = nsurfs+1;
nbins = length(bin_press);
deldistm = 1000*deldistkm;

[vel, com_rows, surfPair_bin] = ...
     loadvars(sectfile,'binPair_vel','com_rows','surfPair_bin');

if     reflevel == -1
    ref_bin = com_rows;
elseif reflevel == 0
    ref_bin = ones(1,length(com_rows));
else   %   1<=reflevel<=maxlevels
    ref_bin = surfPair_bin(reflevel,:);   
end %if

gvel                   = geovelrel(vel,ref_bin,com_rows);

[nproperties,n] = size(properties);
fbox = [];
disp('Calculating Flux Per Depth for Properties...')
for iprop = 1:nproperties
   PropName = [charword( properties(iprop,:) )];
   disp(['      ' PropName])

   if iprop==1
      binPair_prop = ones(nbins,npairs);
   else
      Var          = ['binPair_' PropName];
      Expression   = ['loadvars(sectfile,Var)'];
      command      = ['binPair_prop = ' Expression ';'];
      eval(command)
%     binPair_prop=loadvars(sectfile,'binPair_sal');  
   end %if
  
   command = ['FperDepth_prop = binPair_prop .* gvel;'];
   eval(command)
   
   for ipair = 1:npairs
      Expression   = ['FperDepth_prop(:,ipair) * deldistkm(ipair) * 1000'];
      command      = ['FperDepth_prop(:,ipair) = ' Expression ';'];
      eval(command)
   end %for

   LayerF_prop   = [];

   for ipair = 1:npairs
     LayerFPair_prop   = NaN*ones(1,nlayers);
  
     good_p      = Layer_press(:,ipair); 
     good_surf   = find(~isnan(good_p)); 
  
     if ~isempty(good_surf)
        F_good = integrate(bin_press,FperDepth_prop(:,ipair),good_p(good_surf)); 
       for igood = 1:length(F_good)
         LayerFPair_prop(good_surf(igood))   = F_good(igood);
       end %for
     end %if
 
     LayerF_prop   = [LayerF_prop LayerFPair_prop'];

   end %for

   LayerF_prop  = change(LayerF_prop, '==',NaN,0);

   fbox = [fbox; LayerF_prop; sum(LayerF_prop)];
end %for
return

%---------------------------------------------------------------------------

