
function RWmag = layer_prop_mean(nboxes,nlayers,nproperties, ...
                                 row_beg,eqn_beg,eqn_end,Abase)

% LAYER_PROP_MEAN   Mean property value of entire layer (eqn)
%===================================================================
% LAYER_PROP_MEAN   1.4  93/10/19   Copyright (C) Phil Morgan 1992.
%
% RWmag = layer_prop_mean(nboxes,nlayers,row_beg,eqn_beg,eqn_end,Abase)
% 
% DESCRIPTION:
%    Function to calculate weighted property mean in each layer. 
%    Weighted by Area.  Accounts for geometry sign and also allows
%    for property values that may be negative.
%
% AUTHOR:   Phil Morgan 93-10-05
%==================================================================


    Eqn_means      = []; 
    for ibox = 1:nboxes
        Box_mean_props = []; 

	rows_mass1 = row_beg(ibox)+eqn_beg(1);
	rows_mass2 = row_beg(ibox)+eqn_end(1)+1;     % for total	      
        rows_mass  = rows_mass1:rows_mass2;
	  
	Amass        = Abase(rows_mass,:);
        Amass_sign   = sign(Amass);        % account for geometry signs in A
        eqn_sum_mass = sum(abs(Amass)')';  % row-wise sum to give col vector
        eqn_sum_mass = change(eqn_sum_mass,'==',0,NaN); %NaN for division later

        for iprop = 1:nproperties
	      row1       = row_beg(ibox)+eqn_beg(iprop);
	      row2       = row_beg(ibox)+eqn_end(iprop)+1; % for total
	      rows_prop  = row1:row2;

 	      A_prop         = Abase(rows_prop,:) .* Amass_sign;
              eqn_sum_prop   = sum(A_prop')';
              eqn_sum_prop   = change(eqn_sum_prop,'==',0,NaN); %Nan for div.

      	      Prop_mean      = eqn_sum_prop ./ eqn_sum_mass;

	      Box_mean_props = [Box_mean_props Prop_mean];
	end %for iprop

        Eqn_means = [Eqn_means Box_mean_props];

    end	%for ibox
    clear Amass Box_mean_props rows_mass rows_prop

    RWmag = ones( size(Eqn_means) ) ./ Eqn_means ;
    RWmag = change(RWmag,'==',NaN,0);

return
%-----------------------------------------------------------------------

