function [DL,E,D,bbase,reflevel] = ...
         rhs_menu(geometry,sectfiles,properties,nsurfs,DL,E,D,bbase,reflevel)

% RHS_MENU  Menu for constructing RHS matrices D, bbase
%===================================================================
% RHS_MENU  4.7   93/10/12   Copyright (C)  Phil Morgan  1992
%
% DESCRIPTION:
%    Script for menu of the constructing RHS
% 
% CALLER:   dobox.m
% CALLEE:   build_dl.m build_e.m
%
%
% AUTHOR:   Phil Morgan 92-08-03
%==================================================================


if     nargin == 4
  % ok - minimum allowable input parameters.
  DL = []; E = []; D = []; bbase = [];
elseif nargin == 9
  % ok - pass thru any previous values for output parameters DL,E,D,bbase
else
  error('rhs_menu.m: wrong number of input parameters')
end %if


rhs_opt_stop = 0;
rhs_opt = 0;
while rhs_opt_stop == 0
    disp(' ')
    disp(' 						')
    disp('----- RHS MENU (3) -----			')
    disp(' 						')
    disp('      1) Set Reference level - build DL ')
    disp('      2) Reset Ekman to zero	          ')
    disp('      3) Calculate Ekman		')
    disp(' 					')
    disp('      0) Main Menu - construct RHS	')
    disp('  					')

    rhs_opt = input(' Select a menu number: ');

    if      rhs_opt == 0
	rhs_opt_stop = 1;
	if isempty(DL)
           disp(' ')
	   disp('WARNING: RHS not constructed, reflevel not set.')
           disp(' ')
	   disp('Hit a key to continue')
	   pause
	else
           if exist('E')~=1
	      E = zeros(size(DL));
           end %if
           D = -DL - E;
	   bbase = sum(D')';
        end %if

    elseif rhs_opt == 1
    	reflevel = getinput(['What reflevel do you want' ... 
		' (-1=dcom depth, 0=surface, +n=level) ? '],-1,nsurfs);
    	[DL]     = build_dl(geometry, sectfiles, properties, reflevel);
    		
    elseif  rhs_opt == 2
	if isempty(DL)
          disp('WARNING: RHS not construct, reflevel must be set first')
          disp(' ')
          disp('Hit a key to continue')
	  pause
	else
	   E = zeros(size(DL));
	end %if
        disp(' ')
        disp(' Ekman reset to zero')
    		
    elseif  rhs_opt == 3
        disp(' ')
        disp('------ Wind data -------');
        disp('       1) ECMWF         ');
        disp('       2) Hellerman and Rosenstein ');
        
        wind_opt = input('Select wind climatology data: ');
          if wind_opt == 1
             wind_file = '/home/sloyan/dobox4.2b/mfiles/ecmwfdata.mat';
          elseif wind_opt == 2
             wind_file = '/home/sloyan/data/hrwind/hrwind.mat';
          end
    
      	disp(' Adding ekman flux to RHS ');
  	disp(' ')
      	E = build_e( geometry, sectfiles, properties,wind_file);

    else
	rhs_opt_stop = 0;

    end %if

end %while

return
%--------------------------------------------------------------------
