function [R, N, x] = svd_soln(Adashdash, bdash, rank_num, u,s,v, CW)

% SVD_SOLN   Calculated resolution matrices for SVD solution.
%-----------------------------------------------------------------------
% SVD_SOLN  3.2   93/10/06   Copyright (C) Phil Morgan & Steve Rintoul 1991-3
%
% [R, N, x] = svd_soln(Adashdash, bdash, rank_num, u,s,v, CW)
%
% DESCRIPTION:
%    This routine creates the solution to a particular rank and calculates
%    the resolution matrices of the data and model parameters. 
%
% INPUT:
%   rank_num    = rank required for solution
%   AdashAdash  = RW * A * CW
%   u, s, v,    = from "svd(Adashdash)"
%   CW          = column weighting col vector
%
% OUTPUT:
%   x     = model parameters solution (ref velocities in m/s) v*s-1*u'*bdash
%   R     = model resolution matrix VV' 
%   N     = data  resolution matrix UU'
% AUTHOR: Phil Morgan & Steve Rintoul  91-09-13
%-----------------------------------------------------------------------


if nargin ~= 7
   error('svd_soln.m: wrong number of inputs')
end %if

disp(' ')
disp(' Please wait ... ')
disp(' ')   
invs    = diag( ones(1,rank_num) ./ diag( s(1:rank_num,1:rank_num) )' );
[xdash] = v(:,1:rank_num)*invs*u(:,1:rank_num)'*bdash;
[x]     = CW*xdash;
[R]     = v(:,1:rank_num)*v(:,1:rank_num)';
[N]     = u(:,1:rank_num)*u(:,1:rank_num)';


clear abort invs
%--------------------------------------------------------------------------
