function [meanvalues] = weight_mean(y,w)

%===================================================================
% weight_mean x  3.1   92/08/03   Copyright (C) Phil Morgan 1992.
%
% [meanvalues] = weight_mean(y,w)
%
% DESCRIPTION:
%    Calculates mean of y with each element weighted by w.
%    If y is matrix w can be vector of length y_rows or a matrix
%    of same size(y).  Invalid results are NaN.
% 
% AUTHOR:   Phil Morgan 92-07-28
%==================================================================


TRUE  = 1;
FALSE = 0;


[my,ny]=size(y);
[mw,nw]=size(w);

if my==1 
  Transpose = TRUE;
  y=y';
  [my,ny]=size(y);
end

if mw==1
  w=w';
  [mw,nw]=size(w);
end %if

if ~(my==mw)
   errror( ' must have same rows ');
end %if

if ~(ny==nw)
   w = w( : , ones(1,ny) );
end %if


for icol = 1:ny
  goodi = find( ~isnan(y(:,icol)) ); 
  weighted_tot(icol) = nansum( w( goodi ) );
end %for

meanvalues = nansum(y.*w)./weighted_tot;
if Transpose
   meanvalues = meanvalues';
end %if  
%--------------------------------------------------------------------



