function [value,irow] = firstgood(matrix,badflag)

%======================================================================
% FIRSTGOOD   1.4   92/11/12   Copyright (C) Phil Morgan 1992
%
% [value,irow] = firstgood(matrix, {badflag})
%
% DESCRIPTION:
%    Finds the first good data values from the top for each column in
%    "matrix" where the bad data is flagged with "badflag".
%
% INPUT:
%    matrix  = matrix to find first good value in for each column
%    badflag = optional flag for bad data. Default is NaN.
%              Bad data will be "badflag" AND NaNs in data set.
%
% OUTPUT:
%    value   = row vector of first good values in each column of matrix
%    irow    = row vector of corresponding row index for "value"
%              Results = NaN if no good data in column.
%
% AUTHOR:   Phil Morgan   3-03-92
%=======================================================================

% @(#)firstgood.m  Revision: 1.4    92/11/12   Copyright (C) Phil Morgan 1992  
%=======================================================================
% CHECK INPUTS
if nargin==1
   badflag=NaN;
end %if

[m,n] = size(matrix);
if m==1
   matrix = matrix';
end

if ~isnan(badflag)
  matrix = change(matrix,'==',badflag,NaN);
end %if

% BODY
[mrows,ncols] = size(matrix);
for icol = 1:ncols
  good = find(~isnan(matrix(:,icol)) );
  if length(good)==0
    irow(icol)  = NaN;
    value(icol) = NaN;
  else
    irow(icol)  = min(good);
    value(icol) = matrix(irow(icol),icol);
  end %if
end %for
return
%=======================================================================

